@@ -4,4 +4,4 @@ git clone https://github.com/residuum/PuRestJson.wiki.git /tmp/PuRestJson.wiki/
 
 python create-manual.py
 
-make deken
+make machine=amd64 deken.bits=32 deken
